ziggy.hdmc.hadoop_config

Package ziggy :: Package hdmc :: Module hadoop_config |
[hide private]
[frames] | no frames]

# Module hadoop_config

source code

Variables | [hide private]
| hadoop_home = ``'``/usr/local/hadoop/``'``
| hadoop = ``'``/usr/local/hadoop/bin/hadoop``'``
| hadoop_streaming = ``'``/usr/local/hadoop/contrib/streaming/hadoop``...``
| num_map_tasks = `20`
| shared_tmp_space = ``'``/usr/local/hadoop/user-tmp``'``
| __package__ = `None`

Variables Details | [hide private]

  ### hadoop_streaming Value:
      '/usr/local/hadoop/contrib/streaming/hadoop-0.20.2-streaming.jar'